@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875a.  */
+/* A Bison parser, made by GNU Bison 1.875d.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -136,15 +136,18 @@
 #include <string.h>
 #include <stdlib.h>
 #include "ibConfYacc.h"
+#include "ibConfLex.h"
 
 #define YYERROR_VERBOSE
 
 YY_DECL;
 
 #define YYPARSE_PARAM parse_arg
+#define YYLEX_PARAM priv(YYPARSE_PARAM)->yyscanner
 
 typedef struct
 {
+	yyscan_t yyscanner;
 	ibConf_t *configs;
 	unsigned int configs_length;
 	unsigned int config_index;
@@ -171,6 +174,7 @@ static inline ibBoard_t* current_board( gpib_yyparse_private_t *parse_arg )
 
 void init_gpib_yyparse_private( gpib_yyparse_private_t *priv )
 {
+	priv->yyscanner = 0;
 	priv->configs = NULL;
 	priv->configs_length = 0;
 	priv->config_index = 0;
@@ -195,8 +199,6 @@ int parse_gpib_conf( const char *filename, ibConf_t *configs, unsigned int confi
 		return -1;
 	}
 
-	gpib_yyrestart(infile);
-
 	init_gpib_yyparse_private( &priv );
 	priv.configs = configs;
 	priv.configs_length = configs_length;
@@ -210,13 +212,15 @@ int parse_gpib_conf( const char *filename, ibConf_t *configs, unsigned int confi
 	{
 		init_ibboard( &priv.boards[ i ] );
 	}
-
-	if( gpib_yyparse( &priv ) < 0 )
+	gpib_yylex_init(&priv.yyscanner);
+	gpib_yyrestart(infile, priv.yyscanner);
+	if(gpib_yyparse(&priv))
 	{
 		fprintf(stderr, "libgpib: failed to parse configuration file\n");
 //XXX setIberr()
 		retval = -1 ;
 	}
+	gpib_yylex_destroy(priv.yyscanner);
 	fclose(infile);
 
 	if( retval == 0 )
@@ -246,7 +250,7 @@ int parse_gpib_conf( const char *filename, ibConf_t *configs, unsigned int confi
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 108 "ibConfYacc.y"
+#line 112 "ibConfYacc.y"
 typedef union YYSTYPE {
 int  ival;
 char *sval;
@@ -254,7 +258,7 @@ char bval;
 char cval;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 258 "ibConfYacc.c"
+#line 262 "./ibConfYacc.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -278,22 +282,29 @@ typedef struct YYLTYPE
 
 
 /* Line 214 of yacc.c.  */
-#line 282 "ibConfYacc.c"
+#line 286 "./ibConfYacc.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
+# ifndef YYFREE
+#  define YYFREE free
+# endif
+# ifndef YYMALLOC
+#  define YYMALLOC malloc
+# endif
+
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   define YYSTACK_ALLOC alloca
+#  endif
 # else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
-#   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
-#    endif
+#  if defined (alloca) || defined (_ALLOCA_H)
+#   define YYSTACK_ALLOC alloca
+#  else
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   endif
 #  endif
 # endif
@@ -306,20 +317,21 @@ typedef struct YYLTYPE
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (YYLTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYLTYPE_IS_TRIVIAL) && YYLTYPE_IS_TRIVIAL \
+             && defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  short yyss;
+  short int yyss;
   YYSTYPE yyvs;
     YYLTYPE yyls;
 };
@@ -330,13 +342,13 @@ union yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE) + sizeof (YYLTYPE))	\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE) + sizeof (YYLTYPE))	\
       + 2 * YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
@@ -372,7 +384,7 @@ union yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char yysigned_char;
 #else
-   typedef short yysigned_char;
+   typedef short int yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -470,12 +482,12 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,   128,   128,   129,   130,   131,   138,   149,   159,   160,
-     161,   168,   169,   170,   171,   172,   173,   174,   175,   176,
-     177,   178,   179,   180,   181,   182,   183,   184,   185,   186,
-     191,   198,   209,   210,   211,   219,   220,   221,   222,   223,
-     224,   225,   226,   227,   228,   229,   230,   231,   232,   233,
-     234,   237,   238,   239,   242,   243,   244
+       0,   132,   132,   133,   134,   135,   142,   153,   163,   164,
+     165,   172,   173,   174,   175,   176,   177,   178,   179,   180,
+     181,   182,   183,   184,   185,   186,   187,   188,   189,   190,
+     195,   202,   213,   214,   215,   223,   224,   225,   226,   227,
+     228,   229,   230,   231,   232,   233,   234,   235,   236,   237,
+     238,   241,   242,   243,   246,   247,   248
 };
 #endif
 
@@ -484,21 +496,21 @@ static const unsigned char yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "T_INTERFACE", "T_DEVICE", "T_NAME", 
-  "T_MINOR", "T_BASE", "T_IRQ", "T_DMA", "T_PAD", "T_SAD", "T_TIMO", 
-  "T_EOSBYTE", "T_BOARD_TYPE", "T_PCI_BUS", "T_PCI_SLOT", "T_REOS", 
-  "T_BIN", "T_INIT_S", "T_DCL", "T_XEOS", "T_EOT", "T_MASTER", "T_LLO", 
-  "T_EXCL", "T_INIT_F", "T_AUTOPOLL", "T_NUMBER", "T_STRING", "T_BOOL", 
-  "T_TIVAL", "'{'", "'}'", "'='", "','", "$accept", "input", "interface", 
-  "minor", "parameter", "statement", "device", "option", "assign", 
-  "flags", "oneflag", 0
+  "$end", "error", "$undefined", "T_INTERFACE", "T_DEVICE", "T_NAME",
+  "T_MINOR", "T_BASE", "T_IRQ", "T_DMA", "T_PAD", "T_SAD", "T_TIMO",
+  "T_EOSBYTE", "T_BOARD_TYPE", "T_PCI_BUS", "T_PCI_SLOT", "T_REOS",
+  "T_BIN", "T_INIT_S", "T_DCL", "T_XEOS", "T_EOT", "T_MASTER", "T_LLO",
+  "T_EXCL", "T_INIT_F", "T_AUTOPOLL", "T_NUMBER", "T_STRING", "T_BOOL",
+  "T_TIVAL", "'{'", "'}'", "'='", "','", "$accept", "input", "interface",
+  "minor", "parameter", "statement", "device", "option", "assign", "flags",
+  "oneflag", 0
 };
 #endif
 
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short yytoknum[] =
+static const unsigned short int yytoknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
      265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
@@ -664,13 +676,7 @@ static const unsigned char yystos[] =
 
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
-#define YYERROR		do				\
-			  {				\
-			    yylerrsp = yylsp;		\
-			    *++yylerrsp = yyloc;	\
-			    goto yyerrlab1;		\
-			  }				\
-			while (0)
+#define YYERROR		goto yyerrorlab
 
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
@@ -705,11 +711,11 @@ while (0)
    are run).  */
 
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)		\
+   ((Current).first_line   = (Rhs)[1].first_line,	\
+    (Current).first_column = (Rhs)[1].first_column,	\
+    (Current).last_line    = (Rhs)[N].last_line,	\
+    (Current).last_column  = (Rhs)[N].last_column)
 #endif
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
@@ -753,17 +759,17 @@ do {								\
 
 /*------------------------------------------------------------------.
 | yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yy_stack_print (short *bottom, short *top)
+yy_stack_print (short int *bottom, short int *top)
 #else
 static void
 yy_stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -793,9 +799,9 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylineno = yyrline[yyrule];
+  unsigned int yylno = yyrline[yyrule];
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             yyrule - 1, yylineno);
+             yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
     YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
@@ -832,7 +838,7 @@ int yydebug;
    SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
+#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
 # undef YYMAXDEPTH
 #endif
 
@@ -1036,9 +1042,9 @@ YYLTYPE yylloc;
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	yyssa[YYINITDEPTH];
-  short *yyss = yyssa;
-  register short *yyssp;
+  short int yyssa[YYINITDEPTH];
+  short int *yyss = yyssa;
+  register short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
@@ -1079,6 +1085,7 @@ YYLTYPE yylloc;
   yyssp = yyss;
   yyvsp = yyvs;
   yylsp = yyls;
+
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1104,7 +1111,7 @@ YYLTYPE yylloc;
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *yyvs1 = yyvs;
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 	YYLTYPE *yyls1 = yyls;
 
 	/* Each stack pointer address is followed by the size of the
@@ -1132,7 +1139,7 @@ YYLTYPE yylloc;
 	yystacksize = YYMAXDEPTH;
 
       {
-	short *yyss1 = yyss;
+	short int *yyss1 = yyss;
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
@@ -1261,142 +1268,142 @@ yyreduce:
   yyval = yyvsp[1-yylen];
 
   /* Default location. */
-  YYLLOC_DEFAULT (yyloc, (yylsp - yylen), yylen);
+  YYLLOC_DEFAULT (yyloc, yylsp - yylen, yylen);
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
         case 5:
-#line 132 "ibConfYacc.y"
+#line 136 "ibConfYacc.y"
     {
-				fprintf(stderr, "input error on line %i of %s\n", yylsp[0].first_line, DEFAULT_CONFIG_FILE);
+				fprintf(stderr, "input error on line %i of %s\n", gpib_yyget_lineno(priv(parse_arg)->yyscanner), DEFAULT_CONFIG_FILE);
 				YYABORT;
 			}
     break;
 
   case 6:
-#line 139 "ibConfYacc.y"
+#line 143 "ibConfYacc.y"
     {
 				current_config( parse_arg )->is_interface = 1;
 				if( ++( priv(parse_arg)->config_index ) >= priv(parse_arg)->configs_length )
 				{
 					fprintf(stderr, " too many devices in config file\n");
-					YYABORT;
+					YYERROR;
 				}
 			}
     break;
 
   case 7:
-#line 149 "ibConfYacc.y"
+#line 153 "ibConfYacc.y"
     {
 				priv(parse_arg)->board_index = yyvsp[0].ival;
 				current_config(parse_arg)->defaults.board = yyvsp[0].ival;
 				if(priv(parse_arg)->board_index < priv(parse_arg)->boards_length )
 					snprintf(current_board(parse_arg)->device, sizeof(current_board( parse_arg )->device), "/dev/gpib%i", priv(parse_arg)->board_index);
 				else
-					YYABORT;
+					YYERROR;
 			}
     break;
 
   case 10:
-#line 162 "ibConfYacc.y"
+#line 166 "ibConfYacc.y"
     {
 				fprintf(stderr, "parameter error on line %i of %s\n", yylsp[0].first_line, DEFAULT_CONFIG_FILE);
-				YYABORT;
+				YYERROR;
 			}
     break;
 
   case 11:
-#line 168 "ibConfYacc.y"
+#line 172 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.pad = yyvsp[0].ival;}
     break;
 
   case 12:
-#line 169 "ibConfYacc.y"
+#line 173 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.sad = yyvsp[0].ival - sad_offset;}
     break;
 
   case 13:
-#line 170 "ibConfYacc.y"
+#line 174 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos = yyvsp[0].ival;}
     break;
 
   case 14:
-#line 171 "ibConfYacc.y"
+#line 175 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * REOS;}
     break;
 
   case 15:
-#line 172 "ibConfYacc.y"
+#line 176 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * BIN;}
     break;
 
   case 16:
-#line 173 "ibConfYacc.y"
+#line 177 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * REOS;}
     break;
 
   case 17:
-#line 174 "ibConfYacc.y"
+#line 178 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * XEOS;}
     break;
 
   case 18:
-#line 175 "ibConfYacc.y"
+#line 179 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * BIN;}
     break;
 
   case 19:
-#line 176 "ibConfYacc.y"
+#line 180 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.send_eoi = yyvsp[0].bval;}
     break;
 
   case 20:
-#line 177 "ibConfYacc.y"
+#line 181 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.usec_timeout = yyvsp[0].ival; }
     break;
 
   case 21:
-#line 178 "ibConfYacc.y"
+#line 182 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.usec_timeout = timeout_to_usec( yyvsp[0].ival ); }
     break;
 
   case 22:
-#line 179 "ibConfYacc.y"
+#line 183 "ibConfYacc.y"
     { current_board( parse_arg )->base = yyvsp[0].ival; }
     break;
 
   case 23:
-#line 180 "ibConfYacc.y"
+#line 184 "ibConfYacc.y"
     { current_board( parse_arg )->irq = yyvsp[0].ival; }
     break;
 
   case 24:
-#line 181 "ibConfYacc.y"
+#line 185 "ibConfYacc.y"
     { current_board( parse_arg )->dma = yyvsp[0].ival; }
     break;
 
   case 25:
-#line 182 "ibConfYacc.y"
+#line 186 "ibConfYacc.y"
     { current_board( parse_arg )->pci_bus = yyvsp[0].ival; }
     break;
 
   case 26:
-#line 183 "ibConfYacc.y"
+#line 187 "ibConfYacc.y"
     { current_board( parse_arg )->pci_slot = yyvsp[0].ival; }
     break;
 
   case 27:
-#line 184 "ibConfYacc.y"
+#line 188 "ibConfYacc.y"
     { current_board( parse_arg )->is_system_controller = yyvsp[0].bval; }
     break;
 
   case 28:
-#line 185 "ibConfYacc.y"
+#line 189 "ibConfYacc.y"
     { current_board( parse_arg )->is_system_controller = yyvsp[0].bval; }
     break;
 
   case 29:
-#line 187 "ibConfYacc.y"
+#line 191 "ibConfYacc.y"
     {
 				strncpy(current_board( parse_arg )->board_type, yyvsp[0].sval,
 					sizeof(current_board( parse_arg )->board_type));
@@ -1404,7 +1411,7 @@ yyreduce:
     break;
 
   case 30:
-#line 192 "ibConfYacc.y"
+#line 196 "ibConfYacc.y"
     {
 				strncpy(current_config( parse_arg )->name, yyvsp[0].sval,
 					sizeof(current_config( parse_arg )->name));
@@ -1412,120 +1419,120 @@ yyreduce:
     break;
 
   case 31:
-#line 199 "ibConfYacc.y"
+#line 203 "ibConfYacc.y"
     {
 				current_config( parse_arg )->is_interface = 0;
 				if( ++( priv(parse_arg)->config_index ) >= priv(parse_arg)->configs_length )
 				{
 					fprintf(stderr, "too many devices in config file\n");
-					YYABORT;
+					YYERROR;
 				}
 			}
     break;
 
   case 34:
-#line 212 "ibConfYacc.y"
+#line 216 "ibConfYacc.y"
     {
  				fprintf(stderr, "option error on line %i of config file\n", yylsp[0].first_line );
-				YYABORT;
+				YYERROR;
 			}
     break;
 
   case 35:
-#line 219 "ibConfYacc.y"
+#line 223 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.pad = yyvsp[0].ival; }
     break;
 
   case 36:
-#line 220 "ibConfYacc.y"
+#line 224 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.sad = yyvsp[0].ival - sad_offset; }
     break;
 
   case 37:
-#line 221 "ibConfYacc.y"
+#line 225 "ibConfYacc.y"
     { strncpy(current_config( parse_arg )->init_string,yyvsp[0].sval,60); }
     break;
 
   case 38:
-#line 222 "ibConfYacc.y"
+#line 226 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos = yyvsp[0].ival; }
     break;
 
   case 39:
-#line 223 "ibConfYacc.y"
+#line 227 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * REOS;}
     break;
 
   case 40:
-#line 224 "ibConfYacc.y"
+#line 228 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * REOS;}
     break;
 
   case 41:
-#line 225 "ibConfYacc.y"
+#line 229 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * XEOS;}
     break;
 
   case 42:
-#line 226 "ibConfYacc.y"
+#line 230 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * BIN; }
     break;
 
   case 43:
-#line 227 "ibConfYacc.y"
+#line 231 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.eos_flags |= yyvsp[0].bval * BIN; }
     break;
 
   case 44:
-#line 228 "ibConfYacc.y"
+#line 232 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.send_eoi = yyvsp[0].bval;}
     break;
 
   case 45:
-#line 229 "ibConfYacc.y"
+#line 233 "ibConfYacc.y"
     { current_config( parse_arg )->flags |= CN_AUTOPOLL; }
     break;
 
   case 47:
-#line 231 "ibConfYacc.y"
+#line 235 "ibConfYacc.y"
     { strncpy(current_config( parse_arg )->name,yyvsp[0].sval, sizeof(current_config( parse_arg )->name));}
     break;
 
   case 48:
-#line 232 "ibConfYacc.y"
+#line 236 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.board = yyvsp[0].ival;}
     break;
 
   case 49:
-#line 233 "ibConfYacc.y"
+#line 237 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.usec_timeout = yyvsp[0].ival; }
     break;
 
   case 50:
-#line 234 "ibConfYacc.y"
+#line 238 "ibConfYacc.y"
     { current_config( parse_arg )->defaults.usec_timeout = timeout_to_usec( yyvsp[0].ival ); }
     break;
 
   case 54:
-#line 242 "ibConfYacc.y"
+#line 246 "ibConfYacc.y"
     { current_config( parse_arg )->flags |= CN_SLLO; }
     break;
 
   case 55:
-#line 243 "ibConfYacc.y"
+#line 247 "ibConfYacc.y"
     { current_config( parse_arg )->flags |= CN_SDCL; }
     break;
 
   case 56:
-#line 244 "ibConfYacc.y"
+#line 248 "ibConfYacc.y"
     { current_config( parse_arg )->flags |= CN_EXCLUSIVE; }
     break;
 
 
     }
 
-/* Line 999 of yacc.c.  */
-#line 1529 "ibConfYacc.c"
+/* Line 1010 of yacc.c.  */
+#line 1536 "./ibConfYacc.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1566,18 +1573,33 @@ yyerrlab:
 	{
 	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
+	  const char* yyprefix;
 	  char *yymsg;
-	  int yyx, yycount;
+	  int yyx;
 
-	  yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (yyx = yyn < 0 ? -yyn : 0;
-	       yyx < (int) (sizeof (yytname) / sizeof (char *)); yyx++)
+	  int yyxbegin = yyn < 0 ? -yyn : 0;
+
+	  /* Stay within bounds of both yycheck and yytname.  */
+	  int yychecklim = YYLAST - yyn;
+	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
+	  int yycount = 0;
+
+	  yyprefix = ", expecting ";
+	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-	      yysize += yystrlen (yytname[yyx]) + 15, yycount++;
-	  yysize += yystrlen ("syntax error, unexpected ") + 1;
-	  yysize += yystrlen (yytname[yytype]);
+	      {
+		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
+		yycount += 1;
+		if (yycount == 5)
+		  {
+		    yysize = 0;
+		    break;
+		  }
+	      }
+	  yysize += (sizeof ("syntax error, unexpected ")
+		     + yystrlen (yytname[yytype]));
 	  yymsg = (char *) YYSTACK_ALLOC (yysize);
 	  if (yymsg != 0)
 	    {
@@ -1586,16 +1608,13 @@ yyerrlab:
 
 	      if (yycount < 5)
 		{
-		  yycount = 0;
-		  for (yyx = yyn < 0 ? -yyn : 0;
-		       yyx < (int) (sizeof (yytname) / sizeof (char *));
-		       yyx++)
+		  yyprefix = ", expecting ";
+		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 		      {
-			const char *yyq = ! yycount ? ", expecting " : " or ";
-			yyp = yystpcpy (yyp, yyq);
+			yyp = yystpcpy (yyp, yyprefix);
 			yyp = yystpcpy (yyp, yytname[yyx]);
-			yycount++;
+			yyprefix = " or ";
 		      }
 		}
 	      yyerror (yymsg);
@@ -1616,25 +1635,27 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (yychar == YYEOF)
+      if (yychar <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (yyss < yyssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-	      yydestruct (yystos[*yyssp], yyvsp, yylsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+          /* If at end of input, pop the error token,
+	     then the rest of the stack, then return failure.  */
+	  if (yychar == YYEOF)
+	     for (;;)
+	       {
+		 YYPOPSTACK;
+		 if (yyssp == yyss)
+		   YYABORT;
+		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
+		 yydestruct (yystos[*yyssp], yyvsp, yylsp);
+	       }
         }
-
-      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-      yydestruct (yytoken, &yylval, &yylloc);
-      yychar = YYEMPTY;
-      *++yylerrsp = yylloc;
+      else
+	{
+	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
+	  yydestruct (yytoken, &yylval, &yylloc);
+	  yychar = YYEMPTY;
+	  *++yylerrsp = yylloc;
+	}
     }
 
   /* Else will try to reuse lookahead token after shifting the error
@@ -1642,9 +1663,30 @@ yyerrlab:
   goto yyerrlab1;
 
 
-/*----------------------------------------------------.
-| yyerrlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| yyerrorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+yyerrorlab:
+
+#ifdef __GNUC__
+  /* Pacify GCC when the user code never invokes YYERROR and the label
+     yyerrorlab therefore never appears in user code.  */
+  if (0)
+     goto yyerrorlab;
+#endif
+
+  yyvsp -= yylen;
+  yyssp -= yylen;
+  yystate = *yyssp;
+  yylerrsp = yylsp;
+  *++yylerrsp = yyloc;
+  yylsp -= yylen;
+  goto yyerrlab1;
+
+
+/*-------------------------------------------------------------.
+| yyerrlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 yyerrlab1:
   yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
@@ -1668,9 +1710,8 @@ yyerrlab1:
 
       YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
       yydestruct (yystos[yystate], yyvsp, yylsp);
-      yyvsp--;
-      yystate = *--yyssp;
-      yylsp--;
+      YYPOPSTACK;
+      yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
@@ -1680,7 +1721,7 @@ yyerrlab1:
   YYDPRINTF ((stderr, "Shifting error token, "));
 
   *++yyvsp = yylval;
-  YYLLOC_DEFAULT (yyloc, yylsp, (yylerrsp - yylsp));
+  YYLLOC_DEFAULT (yyloc, yylsp, yylerrsp - yylsp);
   *++yylsp = yyloc;
 
   yystate = yyn;
@@ -1720,7 +1761,7 @@ yyreturn:
 }
 
 
-#line 247 "ibConfYacc.y"
+#line 251 "ibConfYacc.y"
 
 
 
